@@ -18,7 +18,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: cgi.ml,v 1.14 2004/07/16 08:36:42 rwmj Exp $
+ * $Id: cgi.ml,v 1.15 2004/09/27 11:56:41 rwmj Exp $
  *)
 
 open Apache
@@ -141,6 +141,21 @@ let get_post_body r =
   else ""
 
 (* Parsing of the CGI arguments. *)
+module Cgi_args =
+struct
+  let parse s =
+    let assocs = split '&' s in
+    let one_assoc s =
+      try
+	let i = String.index s '=' in
+	String.sub s 0 i, 
+	decode (String.sub s (succ i) (String.length s - i - 1))
+      with
+	| Not_found -> s, ""
+    in
+    List.map one_assoc assocs
+end
+
 let parse_args r = 
   let req_method = Request.method_number r in
   let s = 
@@ -154,16 +169,7 @@ let parse_args r =
 	  get_post_body r
       | _ -> raise (HttpError cHTTP_METHOD_NOT_ALLOWED)
   in
-  let assocs = split '&' s in
-  let one_assoc s =
-    try
-      let i = String.index s '=' in
-      String.sub s 0 i, 
-      decode (String.sub s (succ i) (String.length s - i - 1))
-    with
-      | Not_found -> s, ""
-  in
-  List.map one_assoc assocs
+  Cgi_args.parse s
 
 (* multipart_args: parsing of the CGI arguments for multipart/form-data
    encoding *)
@@ -547,6 +553,39 @@ struct
 
   end
 
+(* Generic expires headers. *)
+module Expires =
+struct
+  let short_weekday = function
+    | 0 -> "Sun" | 1 -> "Mon" | 2 -> "Tue" | 3 -> "Wed"
+    | 4 -> "Thu" | 5 -> "Fri" | 6 -> "Sat" | 7 -> "Sun"
+    | _ -> invalid_arg "short_weekday"
+
+  let short_month = function
+    | 1 -> "Jan" | 2 -> "Feb" | 3 -> "Mar" | 4 -> "Apr"
+    | 5 -> "May" | 6 -> "Jun" | 7 -> "Jul" | 8 -> "Aug"
+    | 9 -> "Sep" | 10 -> "Oct" | 11 -> "Nov" | 12 -> "Dec"
+    | _ -> invalid_arg "short_month"
+
+  let make offset =
+    let t = Unix.time () in
+    let tm = Unix.gmtime (t +. float offset) in
+    Printf.sprintf "%s, %02d %s %04d %02d:%02d:%02d GMT"
+      (short_weekday tm.Unix.tm_wday)
+      tm.Unix.tm_mday
+      (short_month (tm.Unix.tm_mon + 1))
+      (tm.Unix.tm_year + 1900)
+      tm.Unix.tm_hour
+      tm.Unix.tm_min
+      tm.Unix.tm_sec
+
+  let past () = make ((-5) * 60)
+  let short () = make (5 * 60)
+  let medium () = make 86400
+  let long () = make (365 * 2 * 86400)
+
+end
+
 (* Generate a suitable random number for use in random cookies, session IDs,
  * etc.  These numbers are supposed to be very hard to predict.  Current
  * implementation requires /dev/urandom which may not exist on all platforms.
