@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: mod_caml.ml,v 1.6 2004/06/21 09:14:29 rwmj Exp $
+ * $Id: mod_caml.ml,v 1.7 2004/09/27 11:29:55 rwmj Exp $
  *)
 
 (* Note a peculiarity of Apache: it runs all initialization TWICE. See this
@@ -114,94 +114,94 @@ external get_dir_config : Request.t -> dir_config_t
 (*----- Handlers. -----*)
 
 let translate_handler r =
-  try
-    let config = get_server_config r in
-    (match config.translate_handler with
-	 Some handler -> handler r
-       | None -> DECLINED)
-  with
-      Not_found -> DECLINED
+  let config = try Some (get_server_config r) with Not_found -> None in
+  match config with
+    | None -> DECLINED
+    | Some config ->
+	match config.translate_handler with
+	  | Some handler -> handler r
+	  | None -> DECLINED
 
 let check_user_id r =
-  try
-    let config = get_dir_config r in
-    (match config.check_user_id with
-	 Some handler -> handler r
-       | None -> DECLINED)
-  with
-      Not_found -> DECLINED
+  let config = try Some (get_dir_config r) with Not_found -> None in
+  match config with
+    | None -> DECLINED
+    | Some config ->
+	match config.check_user_id with
+	  | Some handler -> handler r
+	  | None -> DECLINED
 
 let auth_checker r =
-  try
-    let config = get_dir_config r in
-    (match config.auth_checker with
-	 Some handler -> handler r
-       | None -> DECLINED)
-  with
-      Not_found -> DECLINED
+  let config = try Some (get_dir_config r) with Not_found -> None in
+  match config with
+    | None -> DECLINED
+    | Some config ->
+	match config.auth_checker with
+	  | Some handler -> handler r
+	  | None -> DECLINED
 
 let access_checker r =
-  try
-    let config = get_dir_config r in
-    (match config.access_checker with
-	 Some handler -> handler r
-       | None -> DECLINED)
-  with
-      Not_found -> DECLINED
+  let config = try Some (get_dir_config r) with Not_found -> None in
+  match config with
+    | None -> DECLINED
+    | Some config ->
+	match config.access_checker with
+	  | Some handler -> handler r
+	  | None -> DECLINED
 
 let type_checker r =
-  try
-    let config = get_dir_config r in
-    (match config.type_checker with
-	 Some handler -> handler r
-       | None -> DECLINED)
-  with
-      Not_found -> DECLINED
+  let config = try Some (get_dir_config r) with Not_found -> None in
+  match config with
+    | None -> DECLINED
+    | Some config ->
+	match config.type_checker with
+	  | Some handler -> handler r
+	  | None -> DECLINED
 
 let fixer_upper r =
-  try
-    let config = get_dir_config r in
-    (match config.fixer_upper with
-	 Some handler -> handler r
-       | None -> DECLINED)
-  with
-      Not_found -> DECLINED
+  let config = try Some (get_dir_config r) with Not_found -> None in
+  match config with
+    | None -> DECLINED
+    | Some config ->
+	match config.fixer_upper with
+	  | Some handler -> handler r
+	  | None -> DECLINED
 
 let logger r =
-  try
-    let config = get_dir_config r in
-    (match config.logger with
-	 Some handler -> handler r
-       | None -> DECLINED)
-  with
-      Not_found -> DECLINED
+  let config = try Some (get_dir_config r) with Not_found -> None in
+  match config with
+    | None -> DECLINED
+    | Some config ->
+	match config.logger with
+	  | Some handler -> handler r
+	  | None -> DECLINED
 
 let header_parser r =
-  try
-    let config = get_dir_config r in
-    (match config.header_parser with
-	 Some handler -> handler r
-       | None -> DECLINED)
-  with
-      Not_found -> DECLINED
+  let config = try Some (get_dir_config r) with Not_found -> None in
+  match config with
+    | None -> DECLINED
+    | Some config ->
+	match config.header_parser with
+	  | Some handler -> handler r
+	  | None -> DECLINED
 
 let post_read_request r =
-  try
-    let config = get_dir_config r in
-    (match config.post_read_request with
-	 Some handler -> handler r
-       | None -> DECLINED)
-  with
-      Not_found -> DECLINED
+  let config = try Some (get_dir_config r) with Not_found -> None in
+  match config with
+    | None -> DECLINED
+    | Some config ->
+	match config.post_read_request with
+	  | Some handler -> handler r
+	  | None -> DECLINED
 
 let ocaml_bytecode_handler r =
-  try
-    let config = get_dir_config r in
-    (match config.ocaml_bytecode_handler with
-	 Some handler -> handler r
-       | None -> DECLINED)
-  with
-      Not_found -> DECLINED
+  let config = try Some (get_dir_config r) with Not_found -> None in
+  match config with
+    | None -> DECLINED
+    | Some config ->
+	match config.ocaml_bytecode_handler with
+	  | Some handler -> handler r
+	  | None -> DECLINED
 
 (*----- Handler registration. -----*)
 
