@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: mod_caml_c.c,v 1.5 2004/08/19 11:13:17 rwmj Exp $
+ * $Id: mod_caml_c.c,v 1.6 2004/09/27 11:29:55 rwmj Exp $
  */
 
 #include "config.h"
@@ -170,17 +170,18 @@ merge_server_config (pool *p, void *base, void *add)
 }
 
 static int
-exception_in_handler (value exn)
+exception_in_handler (value exn, const char *function_name)
 {
   /* Turn HttpError exception into the appropriate return code. */
   value http_error_exn = *caml_named_value ("mod_caml_http_error");
   if (Field (exn, 0) == http_error_exn)
     {
       int status_code = Int_val (Field (exn, 1));
+      fprintf (stderr, "%s: HTTP %d\n", function_name, status_code);
       return status_code;
     }
   /* Unknown other exception: log it and return internal server error. */
-  fputs (caml_format_exception (exn), stderr); fputc ('\n', stderr);
+  fprintf (stderr, "%s: %s\n", function_name, caml_format_exception (exn));
   return HTTP_INTERNAL_SERVER_ERROR;
 }
 
@@ -195,7 +196,7 @@ name (request_rec *r)						\
   arg = Val_request_rec(r);                                     \
   rv = callback_exn (*f, arg);           			\
   if (Is_exception_result (rv))					\
-    return exception_in_handler (Extract_exception (rv));	\
+    return exception_in_handler (Extract_exception (rv), __FUNCTION__); \
   return Result_type_val (rv);					\
 }
 
